import { Component } from '@angular/core';
import { CloudObject, CloudQuery, CloudUser } from '../../lib/ncloud';
import { Router } from '@angular/router';
import { IonicModule } from '@ionic/angular';
import { CommonModule } from '@angular/common';
import { ModalController } from '@ionic/angular'; // 导入 ModalController
import { EditProfileComponent } from './edit-profile.component'; // 假设编辑资料组件名为 EditProfileComponent

@Component({
  selector: 'app-user-dashboard',
  templateUrl: 'user-dashboard.page.html',
  styleUrls: ['user-dashboard.page.scss'],
  imports: [IonicModule, CommonModule],
  standalone: true 
})
export class UserDashboardPage {
 
  user = new CloudUser();
  currentUser: any = null;
     
  // 修改为CloudObject数组类型
  qualification: CloudObject[] = [];

  constructor(private router: Router, private modalCtrl: ModalController) {
    this.getCurrentUser();
  }

  async getCurrentUser() {
    this.currentUser = await this.user.current();
    const query = new CloudQuery('Qualification');
    this.qualification = await query.find();
  }

  async logout() {
    const success = await this.user.logout();
    if (success) {
      this.router.navigate(['/tabs/tab5']); 
    }
  }

  async goToEditProfile() {
    const modal = await this.modalCtrl.create({
      component: EditProfileComponent,
      componentProps: {
        currentUser: this.currentUser
      }
    });

    modal.onDidDismiss().then(async (data) => {
      if (data.data) {
        // 更新用户信息
        this.user.set(data.data);
        await this.user.save();
        this.currentUser = await this.user.current();
      }
    });

    return await modal.present();
  }

  async ngOnInit() {
    const query = new CloudQuery('Qualification');
    this.qualification = await query.find();
    console.log('从数据库加载的资质数据:', this.qualification); // 添加调试日志
  }

  goToUploadQualification() {
    this.router.navigate(['/tabs/tab5/upload-qualification']);
  }
}